@@ -3,6 +3,7 @@
 # Access comments hash
 #------------------------------------------
 use strict;
+use lib '.';
 use Rcs;
 
 Rcs->bindir('/usr/bin');
@@ -15,8 +16,9 @@ $obj->file("testfile");
 my %comments = $obj->comments;
 my $revision;
 foreach $revision (keys %comments) {
+    #my $comments = $comments{$revision} ? $comments{$revision} : 'GGG';
     my $comments = $comments{$revision};
     print "======\n";
     print "Revision: $revision\n";
-    print "$comments\n";
+    print "$comments###\n";
 }
